@@ -36,6 +36,7 @@ from os_ken.ofproto import ofproto_v1_3_parser as parser
 
 from faucet.conf import test_config_condition, InvalidConfigError
 from faucet.valve_of_old import OLD_MATCH_FIELDS
+from faucet.valve_util import LRU_MAX
 
 MIN_VID = 1
 MAX_VID = 4095
@@ -384,12 +385,16 @@ def is_set_field(action):
     return isinstance(action, parser.OFPActionSetField)
 
 
+def is_ct(action):
+    return isinstance(action, parser.NXActionCT)  # pylint: disable=no-member
+
+
 def apply_meter(meter_id):
     """Return instruction to apply a meter."""
     return parser.OFPInstructionMeter(meter_id, ofp.OFPIT_METER)
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def _apply_actions(actions):
     return parser.OFPInstructionActions(ofp.OFPIT_APPLY_ACTIONS, actions)
 
@@ -405,7 +410,7 @@ def apply_actions(actions):
     return _apply_actions(tuple(actions))
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def goto_table(table):
     """Return instruction to goto table.
 
@@ -417,7 +422,7 @@ def goto_table(table):
     return parser.OFPInstructionGotoTable(table.table_id)
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def goto_table_id(table_id):
     """Return instruction to goto table by table ID.
 
@@ -444,7 +449,7 @@ def metadata_goto_table(metadata, mask, table):
     ]
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def set_field(**kwds):
     """Return action to set any field.
 
@@ -478,7 +483,7 @@ def devid_present(vid):
     return vid ^ ofp.OFPVID_PRESENT
 
 
-@functools.lru_cache(maxsize=1024)
+@functools.lru_cache(maxsize=LRU_MAX)
 def push_vlan_act(table, vlan_vid, eth_type=ether.ETH_TYPE_8021Q):
     """Return OpenFlow action list to push Ethernet 802.1Q header with VLAN VID.
 
@@ -493,7 +498,6 @@ def push_vlan_act(table, vlan_vid, eth_type=ether.ETH_TYPE_8021Q):
     ]
 
 
-@functools.lru_cache()
 def dec_ip_ttl():
     """Return OpenFlow action to decrement IP TTL.
 
@@ -503,7 +507,6 @@ def dec_ip_ttl():
     return parser.OFPActionDecNwTtl()
 
 
-@functools.lru_cache(maxsize=1024)
 def pop_vlan():
     """Return OpenFlow action to pop outermost Ethernet 802.1Q VLAN header.
 
@@ -513,7 +516,40 @@ def pop_vlan():
     return parser.OFPActionPopVlan()
 
 
-@functools.lru_cache(maxsize=1024)
+def ct(**kwds):  # pylint: disable=invalid-name
+    """Return connection tracker action.
+
+    Args:
+        kwds (dict): exactly one connection tracker action.
+    Returns:
+        ryu.ofproto.nx_actions.NXActionCT: connection tracker action.
+    """
+    return parser.NXActionCT(**kwds)  # pylint: disable=no-member
+
+
+def ct_clear():
+    """Return clear connection tracker state action.
+
+    Args:
+        kwds (dict): exactly one clear connection tracker state action.
+    Returns:
+        ryu.ofproto.nx_actions.NXActionCTClear: clear connection tracker state action.
+    """
+    return parser.NXActionCTClear()  # pylint: disable=no-member
+
+
+def ct_nat(**kwds):
+    """Return network address translation connection tracker action.
+
+    Args:
+        kwds (dict): exactly one network address translation connection tracker action.
+    Returns:
+        ryu.ofproto.nx_actions.NXActionNAT: network address translation connection tracker action.
+    """
+    return parser.NXActionNAT(**kwds)  # pylint: disable=no-member
+
+
+@functools.lru_cache(maxsize=LRU_MAX)
 def output_port(port_num, max_len=0):
     """Return OpenFlow action to output to a port.
 
@@ -549,7 +585,7 @@ def dedupe_output_port_acts(output_port_acts):
     return [output_port(port) for port in sorted(output_ports)]
 
 
-@functools.lru_cache(maxsize=1024)
+@functools.lru_cache(maxsize=LRU_MAX)
 def output_non_output_actions(flood_acts):
     """Split output actions into deduped actions, output ports, and non-output port actions.
 
@@ -578,7 +614,6 @@ def output_non_output_actions(flood_acts):
     return (deduped_acts, output_ports, nonoutput_actions)
 
 
-@functools.lru_cache()
 def output_in_port():
     """Return OpenFlow action to output out input port.
 
@@ -588,7 +623,7 @@ def output_in_port():
     return output_port(OFP_IN_PORT)
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def output_controller(max_len=MAX_PACKET_IN_BYTES):
     """Return OpenFlow action to packet in to the controller.
 
@@ -618,7 +653,7 @@ def packetouts(port_nums, data):
         data=data)
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def packetout(port_num, data):
     """Return OpenFlow action to packet out to dataplane from controller.
 
@@ -631,7 +666,6 @@ def packetout(port_num, data):
     return packetouts([port_num], data)
 
 
-@functools.lru_cache()
 def barrier():
     """Return OpenFlow barrier request.
 
@@ -657,13 +691,13 @@ def match(match_fields):
     return parser.OFPMatch(**match_fields)
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def valve_match_vid(value):
     return to_match_vid(value, ofp.OFPVID_PRESENT)
 
 
-# See 7.2.3.7 Flow Match Fields (OF 1.3.5)
 MATCH_FIELDS = {
+    # See 7.2.3.7 Flow Match Fields (OF 1.3.5)
     'in_port': OFCtlUtil(ofp).ofp_port_from_user,
     'in_phy_port': str_to_int,
     'metadata': to_match_masked_int,
@@ -703,7 +737,13 @@ MATCH_FIELDS = {
     'mpls_bos': str_to_int,
     'pbb_isid': to_match_masked_int,
     'tunnel_id': to_match_masked_int,
-    'ipv6_exthdr': to_match_masked_int
+    'ipv6_exthdr': to_match_masked_int,
+
+    # Nicira extensions, see ovs-fields(7)
+    'ct_state': to_match_masked_int,
+    'ct_zone': str_to_int,
+    'ct_mark': to_match_masked_int,
+    'ct_label': to_match_masked_int
 }
 
 
@@ -729,7 +769,7 @@ def _match_ip_masked(ipa):
     return (str(ipa.ip), str(ipa.netmask))
 
 
-@functools.lru_cache(maxsize=1024)
+@functools.lru_cache(maxsize=LRU_MAX)
 def build_match_dict(in_port=None, vlan=None, eth_type=None, eth_src=None,
                      eth_dst=None, eth_dst_mask=None, icmpv6_type=None,
                      nw_proto=None, nw_dst=None, metadata=None,
@@ -783,7 +823,7 @@ def build_match_dict(in_port=None, vlan=None, eth_type=None, eth_src=None,
     return match_dict
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def flowmod(cookie, command, table_id, priority, out_port, out_group,
             match_fields, inst, hard_timeout, idle_timeout, flags=0):
     return parser.OFPFlowMod(
@@ -806,7 +846,7 @@ class NullRyuDatapath:
     ofproto = ofp
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def verify_flowmod(flowmod_msg):
     """Verify flowmod can be serialized."""
     flowmod_msg.datapath = NullRyuDatapath()
@@ -973,7 +1013,7 @@ _MSG_KINDS = {
 }
 
 
-@functools.lru_cache()
+@functools.lru_cache(maxsize=LRU_MAX)
 def _msg_kind(ofmsg):
     ofmsg_type = type(ofmsg)
     ofmsg_kind = _MSG_KINDS_TYPES.get(ofmsg_type, None)
